@@ -1,6 +1,5 @@
 # import packages from default or pip library
-from typing_extensions import Annotated, Doc
-from mongoengine import Document, ListField, pre_save
+from mongoengine import Document, ListField
 
 # import packages from this framework
 
@@ -9,9 +8,8 @@ from mongoengine import Document, ListField, pre_save
 class AllowIPsMixin(Document):
     meta = {'abstract': True}
 
-    allow_ips: Annotated[list[str],
-    Doc("Set IPv4 or IPv6 addresses or networks to allow user to access")] = ListField(null=False,
-                                                                                       default=["127.0.0.1"])
+    allow_ips: list[str] = ListField(null=False,
+                                     default=["127.0.0.1"])
 
 
 # define function to control MongoDB document event
