@@ -1,5 +1,8 @@
+"""
+2025.10.26: change designate column type from Annotated to Optional and raw type.
+"""
+
 # import packages from default or pip library
-from typing_extensions import Annotated, Doc
 from sqlmodel import SQLModel, Field
 
 # import packages from this framework
@@ -7,9 +10,8 @@ from sqlmodel import SQLModel, Field
 
 # define Class for Common SQLModel
 class AllowIPsMixin(SQLModel):
-    allow_ips: Annotated[list[str],
-    Doc("Set IPv4 or IPv6 addresses or networks to allow user to access")] = Field(nullable=False,
-                                                                                   default=["127.0.0.1"])
+    allow_ips: list[str] = Field(nullable=False,
+                                 default=["127.0.0.1"])
 
 
 # define function to control SQL event
