@@ -1,6 +1,9 @@
+"""
+2025.10.26: change designate column type from Annotated to Optional and raw type.
+"""
+
 # import packages from default or pip library
 from pycountry import languages as pylanguage
-from typing_extensions import Annotated, Doc
 from sqlmodel import SQLModel, Field
 
 # import packages from this framework
@@ -8,18 +11,15 @@ from sqlmodel import SQLModel, Field
 
 # define Class for Common SQLModel
 class AllowMaxAccessSettingMixin(SQLModel):
-    allow_max_access: Annotated[int,
-    Doc("user setting for max access during trying sign in.")] = Field(nullable=False, default=5, ge=3, le=5)
+    allow_max_access: str = Field(nullable=False, default=5, ge=3, le=5)
 
 
 class LanguageSettingMixin(SQLModel):
-    language: Annotated[str,
-    Doc("language setting for application user.")] = Field(nullable=False)
+    language: str = Field(nullable=False)
 
 
 class DarkModeSettingMixin(SQLModel):
-    is_dark_mode: Annotated[bool,
-    Doc("light or dark mode for application user.")] = Field(nullable=False, default=False)
+    is_dark_mode: str = Field(nullable=False, default=False)
 
 
 # define function to control SQL event
