@@ -21,3 +21,8 @@ class UUIDViewMixin(BaseModel):
 class RegisterDateTimeViewMixin(BaseModel):
     register_dt: Annotated[Optional[datetime],
     Doc("Datetime that the row was added at.")]
+
+
+class UpdateDateTimeViewMixin(BaseModel):
+    update_dt: Annotated[Optional[datetime],
+    Doc("Datetime that the row was updated at.")]
\ No newline at end of file
